Package {Familia}


Title: 'shiny' Application for Population Structure and Ancestry Assessments
Version: 1.0.3
Description: Provides a 'shiny' web application developed by the Breeding Insight team to support pedigree validation and ancestry assessment of plant and animal populations. The app integrates Mendelian error analysis, parentage assignment and genetic composition/ancestry methods to help researchers evaluate genomic relationships through an accessible, web-based interface without requiring command-line tools. Pedigree validation, Mendelian error analysis and parentage assignment build on the 'BIGpopA' package (https://CRAN.R-project.org/package=BIGpopA). Ancestry estimation uses the sparse non-negative matrix factorization method of Frichot et al. (2014) <doi:10.1534/genetics.113.160572> as implemented in the 'LEA' package by Frichot and Francois (2015) <doi:10.1111/2041-210X.12382>. Line and breed composition are estimated using the breed composition regression method of Funkhouser et al. (2017) <doi:10.2527/tas2016.0003>, extended to polyploid species by Sandercock et al. (2025) <doi:10.1002/tpg2.70067>.
License: Apache License (≥ 2)
Encoding: UTF-8
Depends: R (≥ 4.4.0)
Imports: BIGpopA, bs4Dash, config, curl, data.table, dplyr, DT, ggplot2, golem, httr, openxlsx, RColorBrewer, scales, shiny, shinydisconnect, shinyjs, shinyWidgets, tibble, tidyr, vcfR (≥ 1.15.0), withr, zip
Suggests: LEA, spelling, testthat
Language: en-US
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-07-20 18:57:02 UTC; josue.chinchilla
Author: Josue Chinchilla-Vargas [aut, cre], Alexander M. Sandercock [aut], Breeding Insight Team [aut]
Maintainer: Josue Chinchilla-Vargas <josue.chinchilla@ufl.edu>
Repository: CRAN
Date/Publication: 2026-07-29 18:30:17 UTC

Run the Shiny Application

Description

Run the Shiny Application

Usage

run_app(
  onStart = NULL,
  options = list(),
  enableBookmarking = NULL,
  uiPattern = "/",
  ...
)

Arguments

onStart

A function that will be called before the app is actually run. This is only needed for shinyAppObj, since in the shinyAppDir case, a global.R file can be used for this purpose.

options

Named options that should be passed to the runApp call (these can be any of the following: "port", "launch.browser", "host", "quiet", "display.mode" and "test.mode"). You can also specify width and height parameters which provide a hint to the embedding environment about the ideal height/width for the app.

enableBookmarking

Can be one of "url", "server", or "disable". The default value, NULL, will respect the setting from any previous calls to enableBookmarking(). See enableBookmarking() for more information on bookmarking your app.

uiPattern

A regular expression that will be applied to each GET request to determine whether the ui should be used to handle the request. Note that the entire request path must match the regular expression in order for the match to be considered successful.

...

arguments to pass to golem_opts. See ?golem::get_golem_options for more details.

Value

A Shiny application object (of class shiny.appobj), invoked for the side effect of launching the Familia app.

Examples

if(interactive()){
  run_app()
}